CoordinatorNavigator class abstract

Constructors

CoordinatorNavigator({required CoordinatorRouteBuilder routeBuilder, required GlobalKey<NavigatorState> navigatorKey})
factory
CoordinatorNavigator.cupertino({required GlobalKey<NavigatorState> navigatorKey})
factory
CoordinatorNavigator.material({required GlobalKey<NavigatorState> navigatorKey})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

first(WidgetBuilder widgetBuilder) → void
next(WidgetBuilder widgetBuilder) Future<Object?>?
nextReplaceLast(WidgetBuilder widgetBuilder) Future<Object?>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop({bool toFirst = false}) → void
second(WidgetBuilder widgetBuilder) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited